class: CommandLineTool
cwlVersion: v1.1


requirements:
- class: InlineJavascriptRequirement
- class: ResourceRequirement
  ramMin: 3814
  coresMin: 2
- class: DockerRequirement
  dockerPull: yyasumizu/vdjtools
  

inputs:

  unweighted:
    type: boolean?
    inputBinding:
      prefix: "--unweighted"
      position: 5

  amino_acid:
    type: boolean?
    inputBinding:
      prefix: "--amino-acid"
      position: 6

  vdj_file:
    type: File
    inputBinding:
      position: 7

  output_prefix:
    type: string?
    default: "./"
    inputBinding:
      position: 8


outputs:
  
  spectratype_insert_wt_file:
    type: File
    outputBinding:
      glob: "*.insert.wt.txt"

  spectratype_ndn_wt_file:
    type: File
    outputBinding:
      glob: "*.ndn.wt.txt"

  spectratype_aa_wt_file:
    type: File?
    outputBinding:
      glob: "*.aa.wt.txt"

  spectratype_nt_wt_file:
    type: File?
    outputBinding:
      glob: "*.nt.wt.txt"


baseCommand: ["vdjtools", "CalcSpectratype"]


$namespaces:
  s: http://schema.org/

$schemas:
- https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf

label: "VDJtools Calc Spectratype"
s:name: "VDJtools Calc Spectratype"
s:alternateName: "Calculates spectratype, that is, histogram of read counts by CDR3 nucleotide length"

s:downloadUrl: https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/vdjtools-calc-spectratype.cwl
s:codeRepository: https://github.com/Barski-lab/workflows
s:license: http://www.apache.org/licenses/LICENSE-2.0

s:isPartOf:
  class: s:CreativeWork
  s:name: Common Workflow Language
  s:url: http://commonwl.org/

s:creator:
- class: s:Organization
  s:legalName: "Cincinnati Children's Hospital Medical Center"
  s:location:
  - class: s:PostalAddress
    s:addressCountry: "USA"
    s:addressLocality: "Cincinnati"
    s:addressRegion: "OH"
    s:postalCode: "45229"
    s:streetAddress: "3333 Burnet Ave"
    s:telephone: "+1(513)636-4200"
  s:logo: "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png"
  s:department:
  - class: s:Organization
    s:legalName: "Allergy and Immunology"
    s:department:
    - class: s:Organization
      s:legalName: "Barski Research Lab"
      s:member:
      - class: s:Person
        s:name: Michael Kotliar
        s:email: mailto:misha.kotliar@gmail.com
        s:sameAs:
        - id: http://orcid.org/0000-0002-6486-3898


doc: |
  VDJtools is an open-source Java/Groovy-based framework designed to facilitate analysis of
  immune repertoire sequencing (RepSeq) data. VDJtools computes a wide set of statistics and
  is able to perform various forms of cross-sample analysis. Both comprehensive tabular output
  and publication-ready plots are provided.
  
  Calculates spectratype, that is, histogram of read counts by CDR3 nucleotide length. The
  spectratype is useful to detect pathological and highly clonal repertoires, as the spectratype
  of non-expanded T- and B-cells has a symmetric gaussian-like distribution.


s:about: |
  usage: CalcSpectratype [options] [sample1 sample2 sample3 ... if -m is not
                        specified] output_prefix
  -a,--amino-acid            Will use amino-acid CDR3 sequence lengths
                              instead of nucleotide.
  -h                         display help message
  -m,--metadata <filename>   Metadata file. First and second columns should
                              contain file name and sample id. Header is
                              mandatory and will be used to assign column
                              names for metadata.If column named 'time' is
                              present, it will be used to specify time point
                              sequence.
  -u,--unweighted            Will count each clonotype only once, apart
                              from conventional frequency-weighted
                              histogram.